@@ -2,7 +2,7 @@
 /* -----------------------------------------------------------------------------------------------------------
 Software License for The Fraunhofer FDK AAC Codec Library for Android
 
- Copyright  1995 - 2012 Fraunhofer-Gesellschaft zur Frderung der angewandten Forschung e.V.
+ Copyright  1995 - 2013 Fraunhofer-Gesellschaft zur Frderung der angewandten Forschung e.V.
   All rights reserved.
 
  1.    INTRODUCTION
@@ -441,7 +441,7 @@ AAC_DECODER_ERROR
 
   /* set confort noise level which will be inserted while in state 'muting' */
   if (comfNoiseLevel != AACDEC_CONCEAL_PARAM_NOT_SPECIFIED) {
-    if ( (comfNoiseLevel < 0) 
+    if ( (comfNoiseLevel < -1)
       || (comfNoiseLevel > 127) ) {
       return AAC_DEC_SET_PARAM_FAIL;
     }
@@ -762,7 +762,6 @@ int
   CConcealment_UpdateState( hConcealmentInfo,
                             frameOk );
 
-  if ( !frameOk )
   {
     /* Create data for signal rendering according to the selected concealment method and decoder operating mode. */
 
@@ -775,11 +774,13 @@ int
       {
       default:
       case ConcealMethodMute:
-        /* Mute spectral data in case of errors */
-        FDKmemclear(pAacDecoderChannelInfo->pSpectralCoefficient, samplesPerFrame * sizeof(FIXP_DBL));
-        /* Set last window shape */
-        pAacDecoderChannelInfo->icsInfo.WindowShape = hConcealmentInfo->windowShape;
-        appliedProcessing = 1;
+        if (!frameOk) {
+          /* Mute spectral data in case of errors */
+          FDKmemclear(pAacDecoderChannelInfo->pSpectralCoefficient, samplesPerFrame * sizeof(FIXP_DBL));
+          /* Set last window shape */
+          pAacDecoderChannelInfo->icsInfo.WindowShape = hConcealmentInfo->windowShape;
+          appliedProcessing = 1;
+        }
         break;
 
       case ConcealMethodNoise:
@@ -801,7 +802,7 @@ int
                                    pSamplingRateInfo,
                                    samplesPerFrame,
                                    0,  /* don't use tonal improvement */
-                                   0);
+                                   frameOk);
         break;
 
       }
@@ -1527,8 +1528,13 @@ static void
       {
       case ConcealState_Ok:
         if (!frameOk) {
-          /* change to state SINGLE-FRAME-LOSS */
-          pConcealmentInfo->concealState   = ConcealState_Single;
+          if (pConcealCommonData->numFadeOutFrames > 0) {
+            /* change to state SINGLE-FRAME-LOSS */
+            pConcealmentInfo->concealState   = ConcealState_Single;
+          } else {
+            /* change to state MUTE */
+            pConcealmentInfo->concealState = ConcealState_Mute;
+          }
           pConcealmentInfo->cntFadeFrames  = 0;
           pConcealmentInfo->cntValidFrames = 0;
         }
@@ -1561,11 +1567,16 @@ static void
       case ConcealState_FadeOut:
         pConcealmentInfo->cntFadeFrames += 1;  /* used to address the fade-out factors */
         if (pConcealmentInfo->cntValidFrames > pConcealCommonData->numMuteReleaseFrames) {
-          /* change to state FADE-IN */
-          pConcealmentInfo->concealState  = ConcealState_FadeIn;
-          pConcealmentInfo->cntFadeFrames = findEquiFadeFrame( pConcealCommonData,
-                                                               pConcealmentInfo->cntFadeFrames-1,
-                                                               0 /* FadeOut -> FadeIn */);
+          if (pConcealCommonData->numFadeInFrames > 0) {
+            /* change to state FADE-IN */
+            pConcealmentInfo->concealState  = ConcealState_FadeIn;
+            pConcealmentInfo->cntFadeFrames = findEquiFadeFrame( pConcealCommonData,
+                                                                 pConcealmentInfo->cntFadeFrames-1,
+                                                                 0 /* FadeOut -> FadeIn */);
+          } else {
+            /* change to state OK */
+            pConcealmentInfo->concealState = ConcealState_Ok;
+          }
         } else {
           if (pConcealmentInfo->cntFadeFrames >= pConcealCommonData->numFadeOutFrames) {
             /* change to state MUTE */
@@ -1576,9 +1587,14 @@ static void
 
       case ConcealState_Mute:
         if (pConcealmentInfo->cntValidFrames > pConcealCommonData->numMuteReleaseFrames) {
-          /* change to state FADE-IN */
-          pConcealmentInfo->concealState = ConcealState_FadeIn;
-          pConcealmentInfo->cntFadeFrames = pConcealCommonData->numFadeInFrames - 1;
+          if (pConcealCommonData->numFadeInFrames > 0) {
+            /* change to state FADE-IN */
+            pConcealmentInfo->concealState = ConcealState_FadeIn;
+            pConcealmentInfo->cntFadeFrames = pConcealCommonData->numFadeInFrames - 1;
+          } else {
+            /* change to state OK */
+            pConcealmentInfo->concealState = ConcealState_Ok;
+          }
         }
         break;
 
@@ -1590,11 +1606,16 @@ static void
             pConcealmentInfo->concealState = ConcealState_Ok;
           }
         } else {
-          /* change to state FADE-OUT */
-          pConcealmentInfo->concealState  = ConcealState_FadeOut;
-          pConcealmentInfo->cntFadeFrames = findEquiFadeFrame( pConcealCommonData,
-                                                               pConcealmentInfo->cntFadeFrames+1,
-                                                               1 /* FadeIn -> FadeOut */);
+          if (pConcealCommonData->numFadeOutFrames > 0) {
+            /* change to state FADE-OUT */
+            pConcealmentInfo->concealState  = ConcealState_FadeOut;
+            pConcealmentInfo->cntFadeFrames = findEquiFadeFrame( pConcealCommonData,
+                                                                 pConcealmentInfo->cntFadeFrames+1,
+                                                                 1 /* FadeIn -> FadeOut */);
+          } else {
+            /* change to state MUTE */
+            pConcealmentInfo->concealState = ConcealState_Mute;
+          }
         }
         break;
 
@@ -1625,8 +1646,13 @@ static void
       case ConcealState_Ok:
         if (!(pConcealmentInfo->prevFrameOk[1] ||
              (pConcealmentInfo->prevFrameOk[0] && !pConcealmentInfo->prevFrameOk[1] && frameOk))) {
-          /* Fade out only if the energy interpolation algorithm can not be applied! */
-          pConcealmentInfo->concealState   = ConcealState_FadeOut;
+          if (pConcealCommonData->numFadeOutFrames > 0) {
+            /* Fade out only if the energy interpolation algorithm can not be applied! */
+            pConcealmentInfo->concealState   = ConcealState_FadeOut;
+          } else {
+            /* change to state MUTE */
+            pConcealmentInfo->concealState = ConcealState_Mute;
+          }
           pConcealmentInfo->cntFadeFrames  = 0;
           pConcealmentInfo->cntValidFrames = 0;
         }
@@ -1640,11 +1666,16 @@ static void
         pConcealmentInfo->cntFadeFrames += 1;
 
         if (pConcealmentInfo->cntValidFrames > pConcealCommonData->numMuteReleaseFrames) {
-          /* change to state FADE-IN */
-          pConcealmentInfo->concealState  = ConcealState_FadeIn;
-          pConcealmentInfo->cntFadeFrames = findEquiFadeFrame( pConcealCommonData,
-                                                               pConcealmentInfo->cntFadeFrames-1,
-                                                               0 /* FadeOut -> FadeIn */);
+          if (pConcealCommonData->numFadeInFrames > 0) {
+            /* change to state FADE-IN */
+            pConcealmentInfo->concealState  = ConcealState_FadeIn;
+            pConcealmentInfo->cntFadeFrames = findEquiFadeFrame( pConcealCommonData,
+                                                                 pConcealmentInfo->cntFadeFrames-1,
+                                                                 0 /* FadeOut -> FadeIn */);
+          } else {
+            /* change to state OK */
+            pConcealmentInfo->concealState = ConcealState_Ok;
+          }
         } else {
           if (pConcealmentInfo->cntFadeFrames >= pConcealCommonData->numFadeOutFrames) {
             /* change to state MUTE */
@@ -1655,9 +1686,14 @@ static void
 
       case ConcealState_Mute:
         if (pConcealmentInfo->cntValidFrames > pConcealCommonData->numMuteReleaseFrames) {
-          /* change to state FADE-IN */
-          pConcealmentInfo->concealState = ConcealState_FadeIn;
-          pConcealmentInfo->cntFadeFrames = pConcealCommonData->numFadeInFrames - 1;
+          if (pConcealCommonData->numFadeInFrames > 0) {
+            /* change to state FADE-IN */
+            pConcealmentInfo->concealState = ConcealState_FadeIn;
+            pConcealmentInfo->cntFadeFrames = pConcealCommonData->numFadeInFrames - 1;
+          } else {
+            /* change to state OK */
+            pConcealmentInfo->concealState = ConcealState_Ok;
+          }
         }
         break;
 
@@ -1670,11 +1706,16 @@ static void
             pConcealmentInfo->concealState = ConcealState_Ok;
           }
         } else {
-          /* change to state FADE-OUT */
-          pConcealmentInfo->concealState  = ConcealState_FadeOut;
-          pConcealmentInfo->cntFadeFrames = findEquiFadeFrame( pConcealCommonData,
-                                                               pConcealmentInfo->cntFadeFrames+1,
-                                                               1 /* FadeIn -> FadeOut */);
+          if (pConcealCommonData->numFadeOutFrames > 0) {
+            /* change to state FADE-OUT */
+            pConcealmentInfo->concealState  = ConcealState_FadeOut;
+            pConcealmentInfo->cntFadeFrames = findEquiFadeFrame( pConcealCommonData,
+                                                                 pConcealmentInfo->cntFadeFrames+1,
+                                                                 1 /* FadeIn -> FadeOut */);
+          } else {
+            /* change to state MUTE */
+            pConcealmentInfo->concealState = ConcealState_Mute;
+          }
         }
         break;
       } /* End switch(pConcealmentInfo->concealState) */
