@@ -2,7 +2,7 @@
 /* -----------------------------------------------------------------------------------------------------------
 Software License for The Fraunhofer FDK AAC Codec Library for Android
 
- Copyright  1995 - 2012 Fraunhofer-Gesellschaft zur Frderung der angewandten Forschung e.V.
+ Copyright  1995 - 2015 Fraunhofer-Gesellschaft zur Frderung der angewandten Forschung e.V.
   All rights reserved.
 
  1.    INTRODUCTION
@@ -98,6 +98,11 @@ amm-info@iis.fraunhofer.de
 
 #include "sbr_encoder.h"
 
+#define BITRES_MAX_LD   4000
+#define BITRES_MIN_LD    500
+#define BITRATE_MAX_LD 70000 /* Max assumed bitrate for bitres calculation */
+#define BITRATE_MIN_LD 12000 /* Min assumed bitrate for bitres calculation */
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -113,7 +118,7 @@ typedef enum {
   /* initialization errors */
   aac_enc_init_error_start      = 0x2000,
   AAC_ENC_INVALID_HANDLE        = 0x2020,             /*!< The handle passed to the function call was invalid (probably NULL).        */
-  AAC_ENC_INVALID_FRAME_LENGTH  = 0x2080,             /*!< Invalid frame length (must be 1024 or 960).                                */
+  AAC_ENC_INVALID_FRAME_LENGTH  = 0x2080,             /*!< Invalid frame length.                                                      */
   AAC_ENC_INVALID_N_CHANNELS    = 0x20e0,             /*!< Invalid amount of audio input channels.                                    */
   AAC_ENC_INVALID_SFB_TABLE     = 0x2140,             /*!< Internal encoder error.                                                    */
 
@@ -154,7 +159,7 @@ typedef enum {
 
 #define ANC_DATA_BUFFERSIZE 1024      /* ancBuffer size */
 
-#define MAX_TOTAL_EXT_PAYLOADS  (((6) * (1)) + (2+2))
+#define MAX_TOTAL_EXT_PAYLOADS  (((8) * (1)) + (2+2))
 
 
 typedef enum {
@@ -205,6 +210,10 @@ struct AACENC_CONFIG {
   INT   maxBitsPerFrame;        /* maximum number of bits in AU */
   INT   bitreservoir;           /* size of bitreservoir */
 
+  INT   audioMuxVersion;        /* audio mux version in loas/latm transport format */
+
+  UINT  sbrRatio;               /* sbr sampling rate ratio: dual- or single-rate */
+
   UCHAR useTns;                 /* flag: use temporal noise shaping */
   UCHAR usePns;                 /* flag: use perceptual noise substitution */
   UCHAR useIS;                  /* flag: use intensity coding */
@@ -221,6 +230,36 @@ typedef struct {
 
 typedef struct AAC_ENC *HANDLE_AAC_ENC;
 
+/**
+ * \brief Calculate framesize in bits for given bit rate, frame length and sampling rate.
+ *
+ * \param bitRate               Ttarget bitrate in bits per second.
+ * \param frameLength           Number of audio samples in one frame.
+ * \param samplingRate          Sampling rate in Hz.
+ *
+ * \return                      Framesize in bits per frame.
+*/
+INT FDKaacEnc_CalcBitsPerFrame(
+        const INT bitRate,
+        const INT frameLength,
+        const INT samplingRate
+        );
+
+/**
+ * \brief Calculate bitrate in bits per second for given framesize, frame length and sampling rate.
+ *
+ * \param bitsPerFrame          Framesize in bits per frame.
+ * \param frameLength           Number of audio samples in one frame.
+ * \param samplingRate          Sampling rate in Hz.
+ *
+ * \return                      Bitrate in bits per second.
+*/
+INT FDKaacEnc_CalcBitrate(
+        const INT bitsPerFrame,
+        const INT frameLength,
+        const INT samplingRate
+        );
+
 /**
  * \brief Limit given bit rate to a valid value
  * \param hTpEnc transport encoder handle
