@@ -2,7 +2,7 @@
 /* -----------------------------------------------------------------------------------------------------------
 Software License for The Fraunhofer FDK AAC Codec Library for Android
 
- Copyright  1995 - 2012 Fraunhofer-Gesellschaft zur Frderung der angewandten Forschung e.V.
+ Copyright  1995 - 2013 Fraunhofer-Gesellschaft zur Frderung der angewandten Forschung e.V.
   All rights reserved.
 
  1.    INTRODUCTION
@@ -498,7 +498,7 @@ ReadPsData (HANDLE_PS_DEC h_ps_d,          /*!< handle to struct PS_DEC */
     h_ps_d->bPsDataAvail[h_ps_d->bsReadSlot] = ppt_none;
     /* discard all remaining bits */
     nBitsLeft -= startbits - FDKgetValidBits(hBitBuf);
-    while (nBitsLeft) {
+    while (nBitsLeft > 0) {
       int i = nBitsLeft;
       if (i>8) {
         i = 8;
