@@ -1444,6 +1444,13 @@ sbrDecoder_DecodeElement (
     self->flags |= (applyPs) ? SBRDEC_PS_DECODED : 0;
   }
 
+  if (channelMapping[0] == 255 || ((*numOutChannels == 2) && channelMapping[1] == 255))
+    return SBRDEC_UNSUPPORTED_CONFIG;
+  if (!pSbrChannel[0]->SbrDec.LppTrans.pSettings)
+    return SBRDEC_UNSUPPORTED_CONFIG;
+  if (stereo && !pSbrChannel[1]->SbrDec.LppTrans.pSettings)
+    return SBRDEC_UNSUPPORTED_CONFIG;
+
   /* Set strides for reading and writing */
   if (interleaved) {
     strideIn = numInChannels;
